==> flex-escpos-0.1.3.tgz: package/printOrderSlip.js <==
const escpos = require('escpos');
const moment = require('moment');
const currencyFormatter = require('currency-formatter');

const printerFunctions = require('./printerFormatter');


// var printer = new escpos.Printer(device);



function print(dbPrinter, dbPrintout, _orderslip, callback) {
    var printout = {};// require('../terminalInfo.json');
    var hasPrinter = false;
    var orderslip = _orderslip;
    var paperMaxWidth = dbPrinter.paperWidth;
    var printout = dbPrintout;
    var device;

    //setup
    if (dbPrinter.connectionType === 'USB') {
        try {
            device = new escpos.USB();
            hasPrinter = true;
        } catch (err) {
            console.log('No USB Printer found');
        }
    } else if (dbPrinter.connectionType === 'SERIAL') {
        device = new escpos.Serial(dbPrinter.directory, {
            baudRate: 38400,
            autoOpen: false
        });
        hasPrinter = true;
    } else if (dbPrinter.connectionType === 'NET') {
        device = new escpos.Network(dbPrinter.directory);
        hasPrinter = true;
    } else {
        var err = new Error('##printer is not defined in printerDB');
        return callback(err);
    }

    if (hasPrinter) {
        printer = new escpos.Printer(device);

        device.open(function () {
            printContent(printer, paperMaxWidth, printout, orderslip);
            close(printer);
        });
    }

}

function printContent(printer, paperMaxWidth, printout, orderslip) {
    printer
        .font('a')
        .align('ct')
        .style('normal')
        .size(2, 2)
        .text(printout.title)
        .text('');
    printer
        .size(1, 1)
        .text(moment().format('DD/MM/YYYY HH:mm'))
        .text('');
    printer
        .align('lt')
        .size(2, 2)
        .text('Order No.: ' + orderslip.orderNo)
        .text(orderslip.type)
        .text('Table: ' + orderslip.tableNo);
    printer.size(1, 1).style('u').text(printerFunctions.spaceBuilder(paperMaxWidth)).style('normal');
    printer
        .style('normal')
        .text('')
        .size(2, 2)
        .align('ct');

    for (var i = 0; i < orderslip.order.length; i++) {
        printer
            .text(orderslip.order[i].product)
            .text('x' + orderslip.order[i].quantity.toString())
    }

    printer.size(1, 1).style('u').text(printerFunctions.spaceBuilder(paperMaxWidth)).style('normal');
    printer.text('');
    printer
        .align('lt')
        .size(2, 2)
        .style('normal')
        .text('Remark: ' + orderslip.remark)
        .text('');

}

function close(printer) {
    printer
        .cut(true)
        .close();
}

module.exports = print;

==> flex-escpos-0.1.4.tgz: package/printOrderSlip.js <==
const escpos = require('escpos');
const moment = require('moment');
const currencyFormatter = require('currency-formatter');

const printerFunctions = require('./printerFormatter');


// var printer = new escpos.Printer(device);



function print(dbPrinter, dbPrintout, _orderslip, callback) {
    var printout = {};// require('../terminalInfo.json');
    var hasPrinter = false;
    var orderslip = _orderslip;
    var paperMaxWidth = dbPrinter.paperWidth;
    var printout = dbPrintout;
    var device;

    //setup
    if (dbPrinter.connectionType === 'USB') {
        try {
            device = new escpos.USB();
            hasPrinter = true;
        } catch (err) {
            console.log('No USB Printer found');
        }
    } else if (dbPrinter.connectionType === 'SERIAL') {
        device = new escpos.Serial(dbPrinter.directory, {
            baudRate: 38400,
            autoOpen: false
        });
        hasPrinter = true;
    } else if (dbPrinter.connectionType === 'NET') {
        device = new escpos.Network(dbPrinter.directory);
        hasPrinter = true;
    } else {
        var err = new Error('##printer is not defined in printerDB');
        return callback(err);
    }

    if (hasPrinter) {
        printer = new escpos.Printer(device);

        device.open(function () {
            printContent(printer, paperMaxWidth, printout, orderslip);
            close(printer);
            callback();
        });
    }

}

function printContent(printer, paperMaxWidth, printout, orderslip) {
    printer
        .font('a')
        .align('ct')
        .style('normal')
        .size(2, 2)
        .text(printout.title)
        .text('');
    printer
        .size(1, 1)
        .text(moment().format('DD/MM/YYYY HH:mm'))
        .text('');
    printer
        .align('lt')
        .size(2, 2)
        .text('Order No.: ' + orderslip.orderNo)
        .text(orderslip.type)
        .text('Table: ' + orderslip.tableNo);
    printer.size(1, 1).style('u').text(printerFunctions.spaceBuilder(paperMaxWidth)).style('normal');
    printer
        .style('normal')
        .text('')
        .size(2, 2)
        .align('ct');

    for (var i = 0; i < orderslip.orders.length; i++) {
        printer
            .text(orderslip.orders[i].product)
            .text('x' + orderslip.orders[i].quantity.toString())
    }

    printer.size(1, 1).style('u').text(printerFunctions.spaceBuilder(paperMaxWidth)).style('normal');
    printer.text('');
    printer
        .align('lt')
        .size(2, 2)
        .style('normal')
        .text('Remark: ' + orderslip.remark)
        .text('');

}

function close(printer) {
    printer
        .cut(true)
        .close();
}

module.exports = print;
